import React, { ComponentType } from 'react';
import { ThemeOptions } from '../../components/theme/ThemeContext';
import { SxPalette } from './palette';
import { SxSizing } from './sizing';
import { SxSpace } from './space';
import { SxTypography } from './typography';
type SxPseudoProps = {
    _hover?: SxProps;
    _active?: SxProps;
    _before?: SxProps;
    _after?: SxProps;
    _focus?: SxProps;
    _dark?: SxProps;
};
export type SxCSSProperties = React.CSSProperties | SxSpace | SxPalette | SxSizing | SxTypography | {
    shadow?: number | string;
} | SxPseudoProps;
type RootCallbackResult = {
    [key in keyof React.CSSProperties | keyof SxPalette | keyof SxSpace | keyof SxPalette | keyof SxSizing | keyof SxTypography]: any;
};
export type RootCallback = (props: any) => RootCallbackResult;
export type SelectorCSSProperties = {
    [key: string]: SxCSSProperties;
};
export type SelectorCSSPropertiesCallback = {
    [key: string]: RootCallback;
};
export type CSSPropertiesCallback = {
    [key in keyof SxCSSProperties]: (props: any) => any;
};
type SxCallBack = (theme: ThemeOptions) => SxCSSProperties | SelectorCSSProperties;
export type SxProps = SxCallBack | SxCSSProperties | SelectorCSSProperties | {
    label: string;
} | {
    [key: string]: any;
};
export type WithSxProps = {
    className?: string;
    sx?: SxProps;
    ref?: React.Ref<HTMLElement>;
};
export declare function withSx<TProps>(Component: ComponentType<TProps>): React.ForwardRefExoticComponent<React.PropsWithoutRef<TProps & WithSxProps> & React.RefAttributes<unknown>>;
export default withSx;
